#!/usr/bin/env python2
# -*- coding: utf-8 -*-
##################################################
# GNU Radio Python Flow Graph
# Title: Top Block
# Generated: Fri Feb 12 19:46:20 2016
##################################################

from gnuradio import blocks
from gnuradio import eng_notation
from gnuradio import gr
from gnuradio.eng_option import eng_option
from gnuradio.filter import firdes

import osmosdr
import sys
import numpy as np
import time


class top_block(gr.top_block):

    def __init__(self, init_file_path):
        gr.top_block.__init__(self, "Top Block")

        ##################################################
        # Variables
        ##################################################
        self.samp_rate = samp_rate = 20e6
        self.freq = freq = 868e6

        ##################################################
        # Blocks
        ##################################################
        self.osmosdr_sink_0 = osmosdr.sink( args="numchan=" + str(1) + " " + "hackrf=0" )
        self.osmosdr_sink_0.set_sample_rate(samp_rate)
        self.osmosdr_sink_0.set_center_freq(freq, 0)
        self.osmosdr_sink_0.set_freq_corr(0, 0)
        self.osmosdr_sink_0.set_gain(0, 0)
        self.osmosdr_sink_0.set_if_gain(0, 0)
        self.osmosdr_sink_0.set_bb_gain(0, 0)
        self.osmosdr_sink_0.set_antenna("", 0)
        self.osmosdr_sink_0.set_bandwidth(0, 0)

        self.set_src_1(init_file_path)

    def get_samp_rate(self):
        return self.samp_rate

    def set_samp_rate(self, samp_rate):
        self.samp_rate = samp_rate
        self.blocks_throttle_0.set_sample_rate(self.samp_rate)
        self.osmosdr_sink_0.set_sample_rate(self.samp_rate)

    def get_freq(self):
        return self.freq

    def set_freq(self, freq):
        self.freq = freq
        self.osmosdr_sink_0.set_center_freq(self.freq, 0)

    def set_src_1(self, file_path):
        self.lock()
        self.blocks_file_source_0 = blocks.file_source(gr.sizeof_gr_complex*1, str(file_path), False)
        self.connect((self.blocks_file_source_0, 0), (self.osmosdr_sink_0, 0))
        self.unlock()


def main(top_block_cls=top_block, options=None):
    if len(sys.argv) != 1:
        # Output some useful data before replay.
        data = np.memmap(open(sys.argv[1]), mode="r", dtype=np.complex64)
        samples_in_file = len(data)
        print("sum of all samples: %s\n" % samples_in_file)
    else:
        print("Usage: " + sys.argv[0] + " $file1 ($file2)\n")
        sys.exit(1)

    if len(sys.argv) == 2:
        print("Only one argument: " + sys.argv[1])
        tb = top_block_cls(sys.argv[1])
        tb.disconnect(tb.blocks_file_source_0)
        tb.set_src_1(sys.argv[1])
        tb.run()
    elif len(sys.argv) == 3:
        print("Two arguments %s" % sys.argv[1])
        print("first file: %s" % sys.argv[1])
        tb = top_block_cls(sys.argv[1])
        tb.disconnect(tb.blocks_file_source_0)
        while True:
            # first run
            tb.set_src_1(sys.argv[1])
            tb.run()
            time.sleep(5)
            tb.disconnect(tb.blocks_file_source_0)
            # second run
            tb.set_src_1(sys.argv[2])
            tb.run()
            tb.disconnect(tb.blocks_file_source_0)
            time.sleep(5)

if __name__ == '__main__':
        main()
